@@ -25,6 +25,7 @@
 #include "iconcache.h"
 #include "ui.h"
 #include "errors.h"
+#include "window-private.h"
 
 #include <X11/Xatom.h>
 
@@ -690,6 +691,7 @@ scaled_from_pixdata (guchar *pixdata,
 gboolean
 meta_read_icons (MetaScreen     *screen,
                  Window          xwindow,
+                 char           *res_name,
                  MetaIconCache  *icon_cache,
                  Pixmap          wm_hints_pixmap,
                  Pixmap          wm_hints_mask,
@@ -794,7 +796,7 @@ meta_read_icons (MetaScreen     *screen,
           pixmap != None)
         {
           icon_cache->wm_hints_dirty_forced = FALSE;
-          
+
           if (try_pixmap_and_mask (screen->display,
                                    pixmap, mask,
                                    iconp, ideal_width, ideal_height,
@@ -824,7 +826,7 @@ meta_read_icons (MetaScreen     *screen,
           pixmap != None)
         {
           icon_cache->kwm_win_icon_dirty_forced = FALSE;
-          
+
           if (try_pixmap_and_mask (screen->display, pixmap, mask,
                                    iconp, ideal_width, ideal_height,
                                    mini_iconp, ideal_mini_width, ideal_mini_height))
@@ -841,19 +843,26 @@ meta_read_icons (MetaScreen     *screen,
     }
 
   if ((icon_cache->want_fallback &&
-      icon_cache->origin < USING_FALLBACK_ICON) 
+      icon_cache->origin < USING_FALLBACK_ICON)
    || (icon_cache->fallback_icon_dirty_forced &&
        icon_cache->origin == USING_FALLBACK_ICON))
     {
       icon_cache->fallback_icon_dirty_forced = FALSE;
-      
-      get_fallback_icons (screen,
-                          iconp,
-                          ideal_width,
-                          ideal_height,
-                          mini_iconp,
-                          ideal_mini_width,
-                          ideal_mini_height);
+
+      if (res_name != NULL)
+        {
+          *iconp = meta_ui_get_window_icon_from_name (screen->ui, res_name);
+          *mini_iconp = meta_ui_get_mini_icon_from_name (screen->ui, res_name);
+        }
+
+      if (*iconp == NULL || *mini_iconp == NULL)
+        get_fallback_icons (screen,
+                            iconp,
+                            ideal_width,
+                            ideal_height,
+                            mini_iconp,
+                            ideal_mini_width,
+                            ideal_mini_height);
 
       replace_cache (icon_cache, USING_FALLBACK_ICON,
                      *iconp, *mini_iconp);
