@@ -39,12 +39,15 @@
 #define _XOPEN_SOURCE /* for gethostname() */
 
 #include <config.h>
+#include <glib/gi18n-lib.h>
+
 #include "window-props.h"
 #include "errors.h"
 #include "xprops.h"
 #include "frame-private.h"
 #include "group.h"
 #include <X11/Xatom.h>
+#include <X11/extensions/XRes.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
@@ -76,7 +79,6 @@ typedef struct MetaWindowPropHooks
 static MetaWindowPropHooks* find_hooks (MetaDisplay *display,
                                         Atom         property);
 
-
 void
 meta_window_reload_property (MetaWindow *window,
                              Atom        property,
@@ -293,11 +295,56 @@ reload_wm_window_role (MetaWindow    *window,
   meta_window_update_role (window);
 }
 
+static pid_t
+get_local_pid (MetaWindow *window)
+{
+  pid_t pid;
+  XResClientIdSpec spec;
+  long num_ids;
+  XResClientIdValue *client_ids;
+  long i;
+
+  pid = -1;
+
+  spec.client = window->xwindow;
+  spec.mask = XRES_CLIENT_ID_PID_MASK;
+
+  XResQueryClientIds (window->display->xdisplay,
+                      1,
+                      &spec,
+                      &num_ids,
+                      &client_ids);
+
+  for (i = 0; i < num_ids; i++)
+    {
+      if (client_ids[i].spec.mask == XRES_CLIENT_ID_PID_MASK)
+        {
+          pid = XResGetClientPid (&client_ids[i]);
+          break;
+        }
+    }
+
+  XResClientIdsDestroy (num_ids, client_ids);
+
+  return pid;
+}
+
 static void
 reload_net_wm_pid (MetaWindow    *window,
                    MetaPropValue *value,
                    gboolean       initial)
 {
+  pid_t pid;
+
+  pid = get_local_pid (window);
+
+  if (pid != -1)
+    {
+      meta_verbose ("Using XResGetClientPid instead of _NET_WM_PID\n");
+
+      window->net_wm_pid = pid;
+      return;
+    }
   if (value->type != META_PROP_VALUE_INVALID)
     {
       gulong cardinal = (int) value->v.cardinal;
@@ -345,7 +392,6 @@ reload_net_wm_user_time_window (MetaWindow    *window,
                         NoEventMask);
         }
 
-
       /* Obtain the new NET_WM_USER_TIME_WINDOW and register it */
       window->user_time_window = value->v.xwindow;
       if (window->user_time_window != None)
@@ -1593,6 +1639,7 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
     { display->atom__NET_WM_DESKTOP,   META_PROP_VALUE_CARDINAL, reload_net_wm_desktop },
     { display->atom__NET_WM_STRUT,         META_PROP_VALUE_INVALID, reload_struts },
     { display->atom__NET_WM_STRUT_PARTIAL, META_PROP_VALUE_INVALID, reload_struts },
+    { display->atom__GNOME_WM_STRUT_AREA, META_PROP_VALUE_INVALID, reload_struts },
     { display->atom__NET_STARTUP_ID,  META_PROP_VALUE_UTF8,     reload_net_startup_id },
     { display->atom__NET_WM_SYNC_REQUEST_COUNTER, META_PROP_VALUE_SYNC_COUNTER, reload_update_counter },
     { XA_WM_NORMAL_HINTS,              META_PROP_VALUE_SIZE_HINTS, reload_normal_hints },
@@ -1605,8 +1652,14 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
     { 0 },
   };
 
-  MetaWindowPropHooks *table = g_memdup (hooks, sizeof (hooks)),
-    *cursor = table;
+  MetaWindowPropHooks *table, *cursor;
+
+#if GLIB_CHECK_VERSION (2, 68, 0)
+  table = g_memdup2 (hooks, sizeof (hooks));
+#else
+  table = g_memdup (hooks, sizeof (hooks));
+#endif
+  cursor = table;
 
   g_assert (display->prop_hooks == NULL);
 
